[tor-commits] [tor/maint-0.4.2] dirauth: Rename function for better clarity

nickm at torproject.org nickm at torproject.org
Fri Mar 13 20:45:30 UTC 2020


commit 7b4d9fabefa97e1121482ace6bc712cd2b00ff0f
Author: David Goulet <dgoulet at torproject.org>
Date:   Thu Feb 6 09:49:00 2020 -0500

    dirauth: Rename function for better clarity
    
    Signed-off-by: David Goulet <dgoulet at torproject.org>
---
 src/feature/nodelist/dirlist.c  |  2 +-
 src/feature/nodelist/dirlist.h  |  2 +-
 src/feature/nodelist/nodelist.c |  2 +-
 src/test/test_address_set.c     | 13 +++++++------
 4 files changed, 10 insertions(+), 9 deletions(-)

diff --git a/src/feature/nodelist/dirlist.c b/src/feature/nodelist/dirlist.c
index 749ff06a5..ccbb37851 100644
--- a/src/feature/nodelist/dirlist.c
+++ b/src/feature/nodelist/dirlist.c
@@ -67,7 +67,7 @@ add_trusted_dir_to_nodelist_addr_set(const dir_server_t *dir)
 /** Go over the trusted directory server list and add their address(es) to the
  * nodelist address set. This is called everytime a new consensus is set. */
 MOCK_IMPL(void,
-dirlist_add_trusted_addresses, (void))
+dirlist_add_trusted_dir_addresses, (void))
 {
   if (!trusted_dir_servers) {
     return;
diff --git a/src/feature/nodelist/dirlist.h b/src/feature/nodelist/dirlist.h
index d4bdb4ced..c49162f1e 100644
--- a/src/feature/nodelist/dirlist.h
+++ b/src/feature/nodelist/dirlist.h
@@ -44,6 +44,6 @@ void dir_server_add(dir_server_t *ent);
 void clear_dir_servers(void);
 void dirlist_free_all(void);
 
-MOCK_DECL(void, dirlist_add_trusted_addresses, (void));
+MOCK_DECL(void, dirlist_add_trusted_dir_addresses, (void));
 
 #endif /* !defined(TOR_DIRLIST_H) */
diff --git a/src/feature/nodelist/nodelist.c b/src/feature/nodelist/nodelist.c
index 34214880d..9191173c3 100644
--- a/src/feature/nodelist/nodelist.c
+++ b/src/feature/nodelist/nodelist.c
@@ -691,7 +691,7 @@ nodelist_set_consensus(networkstatus_t *ns)
   } SMARTLIST_FOREACH_END(node);
   /* Then, add all trusted configured directories. Some might not be in the
    * consensus so make sure we know them. */
-  dirlist_add_trusted_addresses();
+  dirlist_add_trusted_dir_addresses();
 
   if (! authdir) {
     SMARTLIST_FOREACH_BEGIN(the_nodelist->nodes, node_t *, node) {
diff --git a/src/test/test_address_set.c b/src/test/test_address_set.c
index 81dc6dff5..6e299d779 100644
--- a/src/test/test_address_set.c
+++ b/src/test/test_address_set.c
@@ -33,7 +33,7 @@ mock_networkstatus_get_latest_consensus_by_flavor(consensus_flavor_t f)
 }
 
 static void
-mock_dirlist_add_trusted_addresses(void)
+mock_dirlist_add_trusted_dir_addresses(void)
 {
   return;
 }
@@ -105,8 +105,8 @@ test_nodelist(void *arg)
        mock_networkstatus_get_latest_consensus_by_flavor);
   MOCK(get_estimated_address_per_node,
        mock_get_estimated_address_per_node);
-  MOCK(dirlist_add_trusted_addresses,
-       mock_dirlist_add_trusted_addresses);
+  MOCK(dirlist_add_trusted_dir_addresses,
+       mock_dirlist_add_trusted_dir_addresses);
 
   dummy_ns = tor_malloc_zero(sizeof(*dummy_ns));
   dummy_ns->flavor = FLAV_MICRODESC;
@@ -123,8 +123,9 @@ test_nodelist(void *arg)
   addr_per_node = 1024;
 
   /* No node no nothing. The lookups should be empty. We've mocked the
    * dirlist_add_trusted_addresses in order for _no_ authorities to be added
    * to the filter else it makes this test to trigger many false positive. */
   nodelist_set_consensus(dummy_ns);
 
   /* The address set should be empty. */
@@ -178,7 +179,7 @@ test_nodelist(void *arg)
   UNMOCK(networkstatus_get_latest_consensus);
   UNMOCK(networkstatus_get_latest_consensus_by_flavor);
   UNMOCK(get_estimated_address_per_node);
-  UNMOCK(dirlist_add_trusted_addresses);
+  UNMOCK(dirlist_add_trusted_dir_addresses);
 }
 
 struct testcase_t address_set_tests[] = {
@@ -123,8 +123,9 @@ test_nodelist(void *arg)
 
   /* No node no nothing. The lookups should be empty. We've mocked the
-   * dirlist_add_trusted_addresses in order for _no_ authorities to be added
-   * to the filter else it makes this test to trigger many false positive. */
+   * dirlist_add_trusted_dir_addresses in order for _no_ authorities to be
+   * added to the filter else it makes this test to trigger many false
+   * positive. */
   nodelist_set_consensus(dummy_ns);
 





More information about the tor-commits mailing list